@@ -1,4 +1,4 @@
-/* $Header: /p/tcsh/cvsroot/tcsh/sh.err.c,v 3.52 2010/05/17 19:36:45 christos Exp $ */
+/* $Header: /p/tcsh/cvsroot/tcsh/sh.err.c,v 3.54 2011/01/24 18:17:07 christos Exp $ */
 /*
  * sh.err.c: Error printing routines. 
  */
@@ -34,7 +34,7 @@
 #include "sh.h"
 #include <assert.h>
 
-RCSID("$tcsh: sh.err.c,v 3.52 2010/05/17 19:36:45 christos Exp $")
+RCSID("$tcsh: sh.err.c,v 3.54 2011/01/24 18:17:07 christos Exp $")
 
 /*
  * C Shell
@@ -51,6 +51,7 @@ char   *seterr = NULL;	/* Holds last error if there was one */
 #define ERR_NAME	0x10000000
 #define ERR_SILENT	0x20000000
 #define ERR_OLD		0x40000000
+#define ERR_INTERRUPT	0x80000000
 
 #define ERR_SYNTAX	0
 #define ERR_NOTALLOWED	1
@@ -450,6 +451,12 @@ cleanup_until(void *last_var)
     abort();
 }
 
+int
+cleanup_reset(void)
+{
+    return cleanup_sp > cleanup_mark;
+}
+
 void
 cleanup_until_mark(void)
 {
@@ -604,7 +611,8 @@ stderror(unsigned int id, ...)
 	     * will go to 1/2 else to FSHOUT/FSHDIAG. See flush in sh.print.c.
 	     */
 	    flush();/*FIXRESET*/
-	    haderr = 1;			/* Now to diagnostic output */
+	    if (!(flags & ERR_INTERRUPT))
+		haderr = 1;		/* Now to diagnostic output */
 	    if (flags & ERR_NAME)
 		xprintf("%s: ", bname);/*FIXRESET*/
 	    if ((flags & ERR_OLD)) {
@@ -645,5 +653,6 @@ stderror(unsigned int id, ...)
     if (tpgrp > 0)
 	(void) tcsetpgrp(FSHTTY, tpgrp);
 #endif
-    reset();			/* Unwind */
+	    if (!(flags & ERR_INTERRUPT))
+	reset();		/* Unwind */
 }
